<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AboutBox</name>
    <message>
        <location filename="../ui/aboutbox.ui" line="14"/>
        <source>About FMIT...</source>
        <translation>Über FMIT...</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="28"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="88"/>
        <source>FMIT</source>
        <translation>FMIT</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="98"/>
        <source>&lt;version&gt;</source>
        <translation>&lt;version&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="123"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="143"/>
        <source>Credits</source>
        <translation>Beitragende</translation>
    </message>
    <message>
        <location filename="../ui/aboutbox.ui" line="158"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Most open-source softwares are infeasible without indirect contributions provided through libraries. Thus, big thanks to the following geeks:&lt;br /&gt;&lt;br /&gt;- dsboger for so many little and usefull changes, updates, packaging, etc.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Florian Hars for the tunning scales&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Scott Bahling for the scales in cents&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Jacob Shapiro for his help to make FMIT working under Windows/Cygwin.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;- Translators: Omega9 (Russian), skarmoutsosv (Greek), Pindaro and dsboger (Portuguese and Brazilian Portuguese), Florian Maier (German).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; for the very Fast Fourier Transform.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt;&apos;s team for the GUI library.&lt;br /&gt;&lt;br /&gt;Any contribution of any sort is very welcome!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Ubuntu&apos;; font-size:11pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Die meiste Open-Source-Software ist ohne indirekte Beiträge, die über Bibliotheken bereitgestellt werden, nicht machbar. Deshalb geht ein großes Dankeschön an die folgenden Geeks:&lt;br /&gt;&lt;br /&gt;-dsboger für so viele kleine und nützliche Änderungen, Updates, Verpackungen, etc.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;-Florian Hars for the tunning scales&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- Arnout Engelen for the JACK issues&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;- John Anderson for the microtonal module idea&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;-Scott Bahling für die Skalen in Cent&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;-Jacob Shapiro für seine Hilfe, FMIT unter Windows/Cygwin zum Laufen zu bringen.&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;-Übersetzer: Omega9 (Russisch), Skarmoutsosv (griechisch), Pindaro und dsboger (Portugiesisch), Florian Maier (Deutsch).&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.fftw.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;FFTW3&lt;/span&gt;&lt;/a&gt;&apos; für die sehr schnelle Fourier-Transformation.&lt;br /&gt;&lt;br /&gt;- &lt;a href=&quot;http://www.qt.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Qt&lt;/span&gt;&lt;/a&gt; Team für die GUI-Bibliothek.&lt;br /&gt;&lt;br /&gt;Jeder Beitrag jeglicher Art ist sehr willkommen!&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>ConfigForm</name>
    <message>
        <location filename="../ui/ConfigForm.ui" line="14"/>
        <source>Configuration</source>
        <translation>Konfiguration</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="46"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="60"/>
        <source>Start in full-screen</source>
        <translation>In Vollbildmodus starten</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="82"/>
        <source>Tuning scale</source>
        <translation>Stimmung</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="96"/>
        <source>Chromatic</source>
        <translation>Chromatisch</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="101"/>
        <source>Werckmeister III</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="106"/>
        <source>Kirnberger III</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="111"/>
        <source>Diatonic</source>
        <translation>Diatonisch</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="116"/>
        <source>Meantone (1/4)</source>
        <translation>Mitteltönig (1/4)</translation>
    </message>
    <message>
        <source>Tonality</source>
        <translation type="vanished">Tonalität</translation>
    </message>
    <message>
        <source>Use anglo-saxon or latin note names:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation type="vanished">Anglo-amerikanische, oder romanische Tonnamen verwenden:
Anglo-amerikanisch: C D E F G A B
Romanisch: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="170"/>
        <source>Note names</source>
        <translation>Tonnamen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="188"/>
        <source>Anglo-Saxon</source>
        <translation>Anglo-amerikanisch</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="193"/>
        <source>Latin</source>
        <translation>Romanisch</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="266"/>
        <source>Capture System</source>
        <translation>Aufnahmesystem</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="307"/>
        <source>Auto-detect an available capture system at startup</source>
        <translation>Verfügbares Aufnahmesystem beim Start bestimmen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="323"/>
        <source>Auto detect now</source>
        <translation>Jetzt bestimmen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="332"/>
        <source>JACK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="346"/>
        <source>Client name</source>
        <translation>Client-Name</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="368"/>
        <source>fmit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="415"/>
        <location filename="../ui/ConfigForm.ui" line="418"/>
        <location filename="../ui/ConfigForm.ui" line="428"/>
        <location filename="../ui/ConfigForm.ui" line="431"/>
        <source>Sampling rate of the JACK server</source>
        <translation>Abtastrate des JACK Servers</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="495"/>
        <location filename="../ui/ConfigForm.ui" line="611"/>
        <location filename="../ui/ConfigForm.ui" line="723"/>
        <location filename="../ui/ConfigForm.ui" line="835"/>
        <source>Sampling rate</source>
        <translation>Abtastrate</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="443"/>
        <source>ALSA</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="160"/>
        <location filename="../ui/ConfigForm.ui" line="165"/>
        <location filename="../ui/ConfigForm.ui" line="177"/>
        <location filename="../ui/ConfigForm.ui" line="182"/>
        <source>Use localized note names. e.g.:
anglo-saxon: C D E F G A B
latin: Do Re Mi Fa Sol La Si</source>
        <translation>Verwenden Sie lokalisierte Notennamen, z.B:
angelsächsisch: C D E F G A B
Latein: Do Re Mi Fa Sol La Si</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="457"/>
        <location filename="../ui/ConfigForm.ui" line="573"/>
        <location filename="../ui/ConfigForm.ui" line="689"/>
        <location filename="../ui/ConfigForm.ui" line="801"/>
        <source>Device name</source>
        <translation>Gerätename</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="542"/>
        <location filename="../ui/ConfigForm.ui" line="658"/>
        <location filename="../ui/ConfigForm.ui" line="770"/>
        <location filename="../ui/ConfigForm.ui" line="882"/>
        <source>Do not use a too big sampling rate. 22050Hz should be largely enough in most cases.</source>
        <translation>Verwenden Sie keine zu hohe Abtastrate. 22050Hz sollten in den meisten Fällen ausreichen.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="559"/>
        <source>OSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="567"/>
        <location filename="../ui/ConfigForm.ui" line="570"/>
        <location filename="../ui/ConfigForm.ui" line="586"/>
        <location filename="../ui/ConfigForm.ui" line="589"/>
        <source>The name of the OSS device to connect to</source>
        <translation>Der Name des OSS Geräts mit dem eine Verbindung hergestellt werden soll</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="592"/>
        <source>/dev/dsp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="675"/>
        <source>PortAudio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="683"/>
        <location filename="../ui/ConfigForm.ui" line="686"/>
        <location filename="../ui/ConfigForm.ui" line="696"/>
        <location filename="../ui/ConfigForm.ui" line="699"/>
        <location filename="../ui/ConfigForm.ui" line="795"/>
        <location filename="../ui/ConfigForm.ui" line="798"/>
        <location filename="../ui/ConfigForm.ui" line="808"/>
        <location filename="../ui/ConfigForm.ui" line="811"/>
        <source>The name of the PortAudio device to connect to</source>
        <translation>Der Name des PortAudio Geräts mit dem eine Verbindung hergestellt werden soll</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="476"/>
        <location filename="../ui/ConfigForm.ui" line="703"/>
        <location filename="../ui/ConfigForm.ui" line="815"/>
        <source>default</source>
        <translation>default</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="52"/>
        <location filename="../ui/ConfigForm.ui" line="56"/>
        <source>Raise the window to the whole screen when the program is started
(You can also use the shortcut &apos;f&apos;).</source>
        <translation>Fenster bei Programmstart maximieren
(Es kann auch das Tastaturkürzel &apos;f&apos; verwendet werden).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="67"/>
        <source>Auto-save configuration and layout on exit</source>
        <translation>Konfiguration und Layout beim Beenden automatisch speichern</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="76"/>
        <location filename="../ui/ConfigForm.ui" line="79"/>
        <location filename="../ui/ConfigForm.ui" line="89"/>
        <location filename="../ui/ConfigForm.ui" line="92"/>
        <source>The used tuning scale to determine note frequency values. Useful for tuning historic intruments.</source>
        <translation>Die zur Bestimmung der Notenfrequenzen verwendete Stimmung. Hilfreich für das Stimmen historischer Instrumente.</translation>
    </message>
    <message>
        <source>The used tonality.
Useful to convert note names to a corresponding instrument tonality (e.g. Eb for saxophone, Bb for trumpet).</source>
        <translation type="vanished">Die verwendete Tonalität.
Wird verwendet um Tonnamen auf ein bestimmtes Instrument umzusetzen (z.B. Eb für Saxophon, Bb für Trompete).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="198"/>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="203"/>
        <source>Hindustani</source>
        <translation>Swara-Natation</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="208"/>
        <source>Byzantine</source>
        <translation>Byzantinische Notation</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="274"/>
        <location filename="../ui/ConfigForm.ui" line="277"/>
        <source>The capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Das Aufnahmesystem (z.B. JACK, ALSA, OSS, PortAudio)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="280"/>
        <source>The capture system</source>
        <translation>Aufnahmesystem</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="287"/>
        <location filename="../ui/ConfigForm.ui" line="290"/>
        <source>Selected the capture system (e.g. JACK, ALSA, OSS, PortAudio)</source>
        <translation>Wählt das Aufnahmesystem (z.B. JACK, ALSA, OSS, PortAudio)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="301"/>
        <location filename="../ui/ConfigForm.ui" line="304"/>
        <location filename="../ui/ConfigForm.ui" line="317"/>
        <location filename="../ui/ConfigForm.ui" line="320"/>
        <source>Auto detect a working capture system at FMIT startup.</source>
        <translation>Funktionierendes Aufnahmesystem beim Start von FMIT bestimmen.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="340"/>
        <location filename="../ui/ConfigForm.ui" line="343"/>
        <location filename="../ui/ConfigForm.ui" line="362"/>
        <location filename="../ui/ConfigForm.ui" line="365"/>
        <source>The name of this FMIT instance in the JACK connections.</source>
        <translation>Der Name dieser FMIT Instanz im JACK Verbindungssystem.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="379"/>
        <location filename="../ui/ConfigForm.ui" line="382"/>
        <location filename="../ui/ConfigForm.ui" line="401"/>
        <location filename="../ui/ConfigForm.ui" line="404"/>
        <source>Automatically connect FMIT to the following source at startup (e.g. alsa_pcm:capture_1)</source>
        <translation>FMIT beim Start automatisch mit folgendem Eingang verbinden (z.B. alsa_pcm:capture_1)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="385"/>
        <source>automaticaly connect to...</source>
        <translation>Automatisch verbinden mit...</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="421"/>
        <source>JACK sampling rate</source>
        <translation>JACK Abtastrate</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="451"/>
        <location filename="../ui/ConfigForm.ui" line="454"/>
        <location filename="../ui/ConfigForm.ui" line="470"/>
        <location filename="../ui/ConfigForm.ui" line="473"/>
        <source>The name of the ALSA device to use.</source>
        <translation>Der Name des zu verwendenden ALSA Geräts.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="487"/>
        <location filename="../ui/ConfigForm.ui" line="491"/>
        <location filename="../ui/ConfigForm.ui" line="504"/>
        <location filename="../ui/ConfigForm.ui" line="508"/>
        <location filename="../ui/ConfigForm.ui" line="603"/>
        <location filename="../ui/ConfigForm.ui" line="607"/>
        <location filename="../ui/ConfigForm.ui" line="620"/>
        <location filename="../ui/ConfigForm.ui" line="624"/>
        <location filename="../ui/ConfigForm.ui" line="715"/>
        <location filename="../ui/ConfigForm.ui" line="719"/>
        <location filename="../ui/ConfigForm.ui" line="732"/>
        <location filename="../ui/ConfigForm.ui" line="736"/>
        <location filename="../ui/ConfigForm.ui" line="827"/>
        <location filename="../ui/ConfigForm.ui" line="831"/>
        <location filename="../ui/ConfigForm.ui" line="844"/>
        <location filename="../ui/ConfigForm.ui" line="848"/>
        <source>The chosen sampling rate.
Do not use a too big sampling rate. 22050Hz should be enough in most cases.</source>
        <translation>Die zu verwendende Abtastrate.
Verwenden Sie keine zu hohe Abtastrate. 22050Hz sollten in den meisten Fällen ausreichen.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="525"/>
        <location filename="../ui/ConfigForm.ui" line="528"/>
        <location filename="../ui/ConfigForm.ui" line="641"/>
        <location filename="../ui/ConfigForm.ui" line="644"/>
        <location filename="../ui/ConfigForm.ui" line="753"/>
        <location filename="../ui/ConfigForm.ui" line="756"/>
        <location filename="../ui/ConfigForm.ui" line="865"/>
        <location filename="../ui/ConfigForm.ui" line="868"/>
        <source>Set the sampling rate to the maximum possible value.</source>
        <translation>Abtastrate auf den höchstmöglichen Wert setzen.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="531"/>
        <location filename="../ui/ConfigForm.ui" line="647"/>
        <location filename="../ui/ConfigForm.ui" line="759"/>
        <location filename="../ui/ConfigForm.ui" line="871"/>
        <source>set to max</source>
        <translation>Auf Maximum setzen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="549"/>
        <location filename="../ui/ConfigForm.ui" line="665"/>
        <location filename="../ui/ConfigForm.ui" line="777"/>
        <location filename="../ui/ConfigForm.ui" line="889"/>
        <source>Mix channels if there are multiple (if unchecked, the first channel will be used)</source>
        <translation>Mehrere Eingangskanäle mischen (Andernfalls wird der erste Kanal verwendet)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="787"/>
        <source>Qt</source>
        <translation>Qt</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="916"/>
        <source>Sound Analysis</source>
        <translation>Analyse</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="924"/>
        <location filename="../ui/ConfigForm.ui" line="928"/>
        <location filename="../ui/ConfigForm.ui" line="939"/>
        <location filename="../ui/ConfigForm.ui" line="943"/>
        <source>Time between each sound analysis.
Can be increased to get less CPU usage (but less temporal precision).</source>
        <translation>Zeit zwischen den einzelnen Soundanalysen.
Dieser Wert kann erhöht werden, um bei verringerter Präzision, weniger CPU Belastung zu erzeugen.</translation>
    </message>
    <message>
        <source>Range of possible notes from the lowest to the highest around the A4 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation type="vanished">Bereich der möglichen Notenwerte vom tiefsten bis zum höchsten Ton, relativ zum A4 Referenzton.
Je kleiner der Bereich, desto niedriger die CPU Belastung.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="967"/>
        <source>Notes range</source>
        <translation>Notenbereich</translation>
    </message>
    <message>
        <source>Lowest semitone from the A4 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation type="vanished">Tiefster Halbton relativ zum A4 Referenzton.
In manchen Fällen empfiehlt es sich einen Wert größer -35 zu verwenden, um Rauschen (~50 Hz) zu verhindern.</translation>
    </message>
    <message>
        <source>Highest semitone from the A4 reference note.</source>
        <translation type="vanished">Höchster Halbton relativ zum A4 Referenzton.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1018"/>
        <location filename="../ui/ConfigForm.ui" line="1021"/>
        <source>Filter the sound below the lowest semitone and above the highest semitone to avoid artefacts and noises in all the following steps of the sound analysis.</source>
        <translation>Töne unterhalb des tiefsten und oberhalb des höchsten Halbtons herausfiltern, um Artefakte und Rauschen in allen nachfolgenden Schritten der Analyse zu verhindern.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1024"/>
        <source>Notes range filtering</source>
        <translation>Bereichsfilter</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1070"/>
        <location filename="../ui/ConfigForm.ui" line="1074"/>
        <location filename="../ui/ConfigForm.ui" line="1100"/>
        <location filename="../ui/ConfigForm.ui" line="1104"/>
        <location filename="../ui/ConfigForm.ui" line="1278"/>
        <location filename="../ui/ConfigForm.ui" line="1282"/>
        <source>Ignore all sounds with volume below this threshold [dB]
(Shown as a red line in various views)</source>
        <translation>Alle Töne unterhalb dieser Lautstärke [dB] ignorieren.
(In manchen Ansichten als rote Linie gekennzeichnet)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1131"/>
        <location filename="../ui/ConfigForm.ui" line="1136"/>
        <location filename="../ui/ConfigForm.ui" line="1163"/>
        <location filename="../ui/ConfigForm.ui" line="1168"/>
        <location filename="../ui/ConfigForm.ui" line="1188"/>
        <location filename="../ui/ConfigForm.ui" line="1193"/>
        <source>Ignore weak sub-harmonics.
This threshold is defined between two neighbors frequency components.
Prevents underestimation errors.</source>
        <translation>Schwache Subharmonische ignorieren.
Diese Begrenzung ist zwischen zwei benachbarten Frequenzen definiert.
Verhindert die Ausgabe zu geringer Abweichungen.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1207"/>
        <location filename="../ui/ConfigForm.ui" line="1211"/>
        <location filename="../ui/ConfigForm.ui" line="1240"/>
        <location filename="../ui/ConfigForm.ui" line="1244"/>
        <location filename="../ui/ConfigForm.ui" line="1263"/>
        <location filename="../ui/ConfigForm.ui" line="1267"/>
        <source>Factor defining the window size (from the lowest possible period defined by the notes range).
The bigger this factor, the more stable the analysis. However, by increasing this factor, FMIT will need more CPU and will react slower to sound changes.</source>
        <translation>Faktor, der die Größe des Fensters definiert (von der niedrigst möglichen Periodendauer des Bereichs aus).
Je größer dieser Faktor ist, desto stablier wird die Analyse. Jedoch wird durch das Vergrößern dieses Faktors mehr Rechenleistung benötigt und die Reaktion träger.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1472"/>
        <location filename="../ui/ConfigForm.ui" line="1476"/>
        <location filename="../ui/ConfigForm.ui" line="1487"/>
        <location filename="../ui/ConfigForm.ui" line="1491"/>
        <source>Quantize the analysis results: ignore frequency jumps, fill gaps, ignore short notes.
The smaller the value, the faster the tuner. However, by decreasing the value, the computed frequency will be more unstable.</source>
        <translation>Ergebnisse der Analyse quantisieren: Frequenzsprünge ignorieren, Leerräume auffüllen, zu kurze Töne ignorieren.
Je geringer der Wert, desto schneller das Stimmgerät. Jedoch wird die berechnete Frequenz durch das Verringern dieses Werts weniger stabil.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1538"/>
        <location filename="../ui/ConfigForm.ui" line="1541"/>
        <source>Restore settings as if you just installed FMIT (requires to restart FMIT).</source>
        <translation>Einstellungen zurücksetzen, als ob FMIT gerade frisch installiert worden wäre (Erfordert einen Neustart von FMIT).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1567"/>
        <location filename="../ui/ConfigForm.ui" line="1570"/>
        <source>Use these settings and quit the configuration panel (it is required to click on the &quot;Save settings&quot; button to permanently keep these settings for each FMIT start)</source>
        <translation>Diese Einstellungen übernehmen und Konfigurationsdialog schließen (Um diese Einstellungen dauerhaft zu speichern, benutzen Sie die Schaltfläche &quot;Einstellungen speichern&quot;)</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1586"/>
        <location filename="../ui/ConfigForm.ui" line="1589"/>
        <source>Discard any changes and quit the configuration panel</source>
        <translation>Alle Änderungen verwerfen und Konfigurationsdialog schließen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="932"/>
        <source>Refresh time</source>
        <translation>Aktualisierungsintervall</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="128"/>
        <source>Transposition</source>
        <translation>Transponierung</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="238"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;To get more options, right-click every view to show up their properties!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body&gt;
&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Weitere Optionen sind mittels Rechtsklick zugängig!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="947"/>
        <location filename="../ui/ConfigForm.ui" line="1495"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1033"/>
        <source>Rectangular filter: bad precision, but very fast</source>
        <translation>Rechteckfilter: Ungenau, jedoch aüßerst schnell</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1046"/>
        <source>FIR filter: good precision, but more costly in CPU usage</source>
        <translation>FIR Filter: Gute Genauigkeit, dafür aber rechenintensiv</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1056"/>
        <location filename="../ui/ConfigForm.ui" line="1059"/>
        <source>Algorithm settings</source>
        <translation>Algorithmuseinstellungen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1062"/>
        <source>Algorithm</source>
        <translation>Algorithmus</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1108"/>
        <location filename="../ui/ConfigForm.ui" line="1173"/>
        <source> dB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1198"/>
        <source>Use sub-harmonic audibility threshold</source>
        <translation>Subharmonische begrenzen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1271"/>
        <source>Window size factor</source>
        <translation>Fenstergröße</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1286"/>
        <source>Volume threshold</source>
        <translation>Lautstärke begrenzen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1296"/>
        <location filename="../ui/ConfigForm.ui" line="1299"/>
        <source>Frequency refinement settings</source>
        <translation>Verfeinerungseinstellungen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1302"/>
        <source>Frequency refinement</source>
        <translation>Verfeinerung</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1311"/>
        <location filename="../ui/ConfigForm.ui" line="1314"/>
        <location filename="../ui/ConfigForm.ui" line="1396"/>
        <location filename="../ui/ConfigForm.ui" line="1399"/>
        <source>Use a refinement method in frequency domain: compute the mean of the quasi-harmonic related spectral peaks (the option allows to chose the number of harmonics to use).</source>
        <translation>Eine Verfeinerung im Frequenzbereich verwenden: Das arithmetische Mittel der quasiharmonischen Spitzen im Spektrum wird berechnet (Diese Option bestimmt die Anzahl der zu verwendenden Harmonischen).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1324"/>
        <location filename="../ui/ConfigForm.ui" line="1327"/>
        <location filename="../ui/ConfigForm.ui" line="1342"/>
        <location filename="../ui/ConfigForm.ui" line="1345"/>
        <location filename="../ui/ConfigForm.ui" line="1373"/>
        <location filename="../ui/ConfigForm.ui" line="1376"/>
        <source>Use a refinement method in time domain: compute the mean of various period lengths (the option allows to chose the number of periods to use).</source>
        <translation>Eine Verfeinerung im Zeitbereich verwenden: Das arithmetische Mittel der verschiedenen Periodenlängen wird berechnet (Diese Option bestimmt die Anzahl der zu verwendenden Perioden).</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1427"/>
        <location filename="../ui/ConfigForm.ui" line="1432"/>
        <source>Frequency domain fundamental refinement:
mean of the fundamental relative frequencies of the harmonics.
Choose the number of harmonics to use.</source>
        <translation>Verfeinerung im Frequenzbereich:
Arithmetisches Mittel der Grundfreqenzen der Harmonischen.
Legen Sie die Anzahl der zu verwendenden Harmonischen fest.</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1317"/>
        <source>Maximum number of harmonics</source>
        <translation>Max. Harmonische</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1330"/>
        <source>Maximum number of periods</source>
        <translation>Max. Perioden</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1455"/>
        <location filename="../ui/ConfigForm.ui" line="1458"/>
        <source>Quantizer settings</source>
        <translation>Quantisierer</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1461"/>
        <source>Quantizer</source>
        <translation>Quantisierereinstellungen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1480"/>
        <source>Latency</source>
        <translation>Latenz</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1544"/>
        <source>Restore &amp;factory settings</source>
        <translation>Auf &amp;Werkseinstellungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1573"/>
        <source>&amp;OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/ConfigForm.ui" line="1592"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>CustomInstrumentTunerForm</name>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1067"/>
        <source>Restore Factory Settings</source>
        <translation>Auf Werkseinstellungen zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1054"/>
        <source>This operation is NOT reversible.
Are you sure you want to lose all your current settings ?</source>
        <translation>Dieser Vorgang kann nicht rückgängig gemacht werden.
Sollen Ihre aktuellen Einstellungen verworfen werden?</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1067"/>
        <source>You can now restart FMIT to get back factory settings</source>
        <translation>Sie können FMIT nun neu starten um zu den Werkseinstellungen zurückzukehren</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1174"/>
        <source>Transposition in number of semitones relative to %1.
Useful to convert note names to a corresponding transposing instrument (e.g. %2 for saxophone, %3 for trumpet).</source>
        <translation>Transposition in Halbtönen relativ zu %1.
Nützlich um Notennamen für ein transponierendes Instrument umzuwandeln (z.B. %2 für Saxofon, %3 für Trompete).</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1187"/>
        <source>The base tunning frequency (the %1 frequency)</source>
        <translation>Die grundlegende Stimmungsfrequenz (die %1 Frequenz)</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1194"/>
        <source>Allows to add an offset to the reference %1</source>
        <translation>Ermöglicht eine Verschiebung zur Referenz %1</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1198"/>
        <source>Range of possible notes from the lowest to the highest around the %1 reference note.
Smaller the range, smaller the CPU usage.</source>
        <translation>Tonumfang von der tiefsten zur höchsten Note um die Referenznote %1.
Je geringer der Umfang, desto geringer ist die CPU-Belastung.</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1203"/>
        <source>Lowest semitone from the %1 reference note.
It can useful to put it higher than -35 to avoid disturbance from the sector alimentation (~50hz).</source>
        <translation>Tiefster Halbton von der Referenznote %2.
Ein Wert oberhalb von -35 kann zur Vermeidung von Störeinflüssen aufgrund der 50Hz-Wechselstrom-Netzfrequenz hilfreich sein.</translation>
    </message>
    <message>
        <location filename="../src/CustomInstrumentTunerForm.cpp" line="1210"/>
        <source>Highest semitone from the %1 reference note.</source>
        <translation>Höchster Halbton von der Referenznote %1 aus.</translation>
    </message>
</context>
<context>
    <name>DialView</name>
    <message>
        <location filename="../src/modules/DialView.cpp" line="15"/>
        <source>Dial</source>
        <translation>Stimmung</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="22"/>
        <source>Show tolerance</source>
        <translation>Toleranz anzeigen</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="28"/>
        <source>Show trace</source>
        <translation>Spur anzeigen</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="34"/>
        <source>Use cents</source>
        <translation>Cents verwenden</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="42"/>
        <source>Scale range</source>
        <translation>Anzeigebereich</translation>
    </message>
    <message>
        <location filename="../src/modules/DialView.cpp" line="50"/>
        <source>Scale range (in cents)</source>
        <translation>Anzeigebereich (In Cents)</translation>
    </message>
</context>
<context>
    <name>GLErrorHistory</name>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="75"/>
        <source>Error history</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="82"/>
        <source>Keep previous notes</source>
        <translation>Vorige Töne beibehalten</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="88"/>
        <source>Use cents</source>
        <translation>Cents verwenden</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="96"/>
        <source>Scale range</source>
        <translation>Anzeigebereich</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="104"/>
        <source>Scale range (in cents)</source>
        <translation>Anzeigebereich (In Cents)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLErrorHistory.cpp" line="229"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>GLFT</name>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="52"/>
        <source>dB scale</source>
        <translation>dB Skala</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="61"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="71"/>
        <source>window length</source>
        <translation>Fenstergröße</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="83"/>
        <source>- Press left mouse button to move the view</source>
        <translation>- Halten Sie die linke Maustaste gedrückt um die Ansicht zu verschieben</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="86"/>
        <source>- Press SHIFT key and left mouse button to zoom in and out</source>
        <translation>- Halten Sie die Shift-Taste und die linke Maustaste gedrückt um hinein-/herauszuzoomen</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="89"/>
        <source>- Double-click to reset the view</source>
        <translation>- Doppelklicken Sie um die Ansicht zurückzusetzen</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="177"/>
        <source>Frequency %1 [Hz]</source>
        <translation>Frequenz %1 [Hz]</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFT.cpp" line="39"/>
        <location filename="../src/modules/GLFT.cpp" line="253"/>
        <source>Fourier Transform</source>
        <translation>Fourieranalyse</translation>
    </message>
</context>
<context>
    <name>GLFreqStruct</name>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="44"/>
        <location filename="../src/modules/GLFreqStruct.cpp" line="53"/>
        <source>Number of harmonics</source>
        <translation>Anzahl Harmonische</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="182"/>
        <source>Harmonics&apos; amplitude</source>
        <translation>Oberton-Amplitude</translation>
    </message>
    <message>
        <location filename="../src/modules/GLFreqStruct.cpp" line="33"/>
        <source>Harmonics</source>
        <translation>Harmonische</translation>
    </message>
</context>
<context>
    <name>GLGraph</name>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="43"/>
        <source>Show Wave Form</source>
        <translation>Signalverlauf anzeigen</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="49"/>
        <source>Auto scale</source>
        <translation>Automatisch skalieren</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="57"/>
        <location filename="../src/modules/GLGraph.cpp" line="64"/>
        <source>Scale factor</source>
        <translation>Skalierungsfaktor</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="78"/>
        <location filename="../src/modules/GLGraph.cpp" line="85"/>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="99"/>
        <location filename="../src/modules/GLGraph.cpp" line="106"/>
        <source>Max height</source>
        <translation>Max. Höhe</translation>
    </message>
    <message>
        <location filename="../src/modules/GLGraph.cpp" line="34"/>
        <location filename="../src/modules/GLGraph.cpp" line="267"/>
        <source>Captured Sound</source>
        <translation>Aufnahme</translation>
    </message>
</context>
<context>
    <name>GLSample</name>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="34"/>
        <source>Waveform</source>
        <translation>Wellenform</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="43"/>
        <source>Show fading</source>
        <translation>Fading anzeigen</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="50"/>
        <location filename="../src/modules/GLSample.cpp" line="58"/>
        <source>Number of fading</source>
        <translation>Fadinganzahl</translation>
    </message>
    <message>
        <location filename="../src/modules/GLSample.cpp" line="127"/>
        <source>Waveform&apos;s period</source>
        <translation>Wellenform-Periode</translation>
    </message>
</context>
<context>
    <name>GLStatistics</name>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="200"/>
        <source>Reset statistics</source>
        <translation>Statistik zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="205"/>
        <source>Keep notes when hidden</source>
        <translation>Töne behalten wenn versteckt</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="213"/>
        <source>Keep n values</source>
        <translation>n Werte behalten</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="222"/>
        <source>Keep this number of values in the computation of the statistics</source>
        <translation>Diese Anzahl von Werten zur Berechnung der Statistik behalten</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="236"/>
        <source>Show standard deviation</source>
        <translation>Standardabweichung anzeigen</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="242"/>
        <source>Scale auto</source>
        <translation>Automatisch skalieren</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="251"/>
        <source>Scale min</source>
        <translation>Min. Skalierung</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="260"/>
        <source>Scale min value (in semi-tones)</source>
        <translation>Min. Skalierung (In Halbtönen)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="278"/>
        <source>Scale max</source>
        <translation>Max. Skalierung</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="287"/>
        <source>Scale max value (in semi-tones)</source>
        <translation>Max. Skalierung (In Halbtönen)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="303"/>
        <source>Show tolerance</source>
        <translation>Toleranz anzeigen</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="309"/>
        <source>Use cents</source>
        <translation>Cents verwenden</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="317"/>
        <source>Scale range</source>
        <translation>Skalierbereich</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="325"/>
        <source>Scale range (in cents)</source>
        <translation>Skalierbereich (In Cents)</translation>
    </message>
    <message>
        <location filename="../src/modules/GLStatistics.cpp" line="192"/>
        <location filename="../src/modules/GLStatistics.cpp" line="437"/>
        <source>Statistics</source>
        <translation>Statistik</translation>
    </message>
</context>
<context>
    <name>GLVolumeHistory</name>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="49"/>
        <source>Volume history</source>
        <translation>Lautstärke</translation>
    </message>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="59"/>
        <source>Keep previous notes</source>
        <translation>Vorige Töne beibehalten</translation>
    </message>
    <message>
        <location filename="../src/modules/GLVolumeHistory.cpp" line="128"/>
        <source>Volume</source>
        <translation>Lautstärke</translation>
    </message>
</context>
<context>
    <name>InstrumentTunerForm</name>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="14"/>
        <source>Free Music Instrument Tuner</source>
        <translation>Kostenloser Musikinstrumentenstimmer</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="55"/>
        <source>K
e
e
p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="61"/>
        <source>K</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="168"/>
        <source>Note Stability</source>
        <translation>Tonstabilität</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="192"/>
        <source>Tuning Frequency</source>
        <translation>Stimmton</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="227"/>
        <source> Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="256"/>
        <source>Offset</source>
        <translation>Versatz</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="284"/>
        <source> cents</source>
        <translation> Cent</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="348"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="351"/>
        <source>The recognized note</source>
        <translation>Der erkannte Ton</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="49"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="52"/>
        <source>Keep the data in the error and volume views (shortcut &quot;k&quot;).</source>
        <translation>Daten in Fehler- und Lautstärkeanzeige beibehalten (Tastaturkürzel &quot;k&quot;).</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="111"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="116"/>
        <source>Volume in dB.
Computed in the frequency domain, from the maximum bin.
The maximum is reached when the signal energy is maximal NOT when the sound is saturated in the time domain.</source>
        <translation>Lautstärke in dB.
Berechnung im Frequenzbereich.
Der maximale Wert wird erreicht wenn die Signalstärke maximal ist, NICHT wenn das Signal im Zeitbereich gesättigt ist.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="151"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="158"/>
        <source>According to the following colors:
red       : the capture system is not working.
grey     : the capture system is OK, but there is not enough sound.
orange : the analysis conditions are bad (like saturation)
green   : a note is beeing analyzed and analysis conditions are OK.</source>
        <translation>Bedeutung der Farben:
Rot: Das Aufnahmesystem funktioniert nicht.
Grau: Das Aufnahmesystem funktioniert, aber das Signal ist zu schwach.
Orange: Schlechte Bedingungen für die Analyse (z.B. Sättgung).
Grün: Ein Ton wird analysiert und die Analysebedingungen sind gut.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="221"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="224"/>
        <source>The base tunning frequency (the A4 frequency)</source>
        <translation>Der Stimmton (A4 Frequenz)</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="250"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="253"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="278"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="281"/>
        <source>Offset in cents from the base tuning frequency</source>
        <translation>Versatz in Cents vom Stimmton</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="322"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="325"/>
        <source>The frequency of the current note in Hertz.</source>
        <translation>Die Frequenz des aktuellen Tons in Hertz.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="376"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="379"/>
        <source>The target frequency of the current note in Hertz.</source>
        <translation>Die Soll-Frequenz des aktuellen Tons in Hertz.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="408"/>
        <source>Views</source>
        <translation>Ansichten</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="422"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="444"/>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="447"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="450"/>
        <source>Pause: the capture, the sound analysis and all views.</source>
        <translation>Pause: Die Aufnahme, Analyse sowie alle Ansichten anhalten.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="480"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="483"/>
        <source>Save configuration panel settings, views settings and the window size.</source>
        <translation>Speichert die Konfiguration und Anordnung der Ansichten und die Größe des Fensters.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="501"/>
        <location filename="../ui/InstrumentTunerForm.ui" line="504"/>
        <source>Invoke the about box.</source>
        <translation>Zeigt den Informationsdialog an.</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="453"/>
        <source>Space</source>
        <translation>Leertaste</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="465"/>
        <source>Configure</source>
        <translation>Konfiguration</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="477"/>
        <source>Save settings</source>
        <translation>Einstellungen speichern</translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="486"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/InstrumentTunerForm.ui" line="498"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
</context>
<context>
    <name>MicrotonalView</name>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="182"/>
        <source>Unkown filename: &apos;</source>
        <translation>Datei nicht gefunden: &apos;</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="286"/>
        <source>Microtonal</source>
        <translation>Mikrotonal</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="287"/>
        <source>Used scale</source>
        <translation>Verwendetes Tonsystem</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="304"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="311"/>
        <source>Root&apos;s octave</source>
        <translation>Oktave des Grundtons</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="325"/>
        <source>Keep root to left side</source>
        <translation>Grundton links ausrichten</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="330"/>
        <source>Load Scala file ...</source>
        <translation>Scala-Datei öffnen...</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="803"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="810"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="842"/>
        <location filename="../src/modules/MicrotonalView.cpp" line="846"/>
        <source>Open scale file</source>
        <translation>Tonsystem öfnen</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="842"/>
        <source>Scale name already exist</source>
        <translation>Das Tonsystem ist bereits vorhanden</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="846"/>
        <source>Invalid file content !</source>
        <translation>Ungültiger Dateiinhalt!</translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="927"/>
        <source>&lt;b&gt;name:&lt;/b&gt; </source>
        <translation>&lt;b&gt;Name:&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="928"/>
        <source>&lt;b&gt;number of ratio:&lt;/b&gt; </source>
        <translation>&lt;b&gt;Anzahl der Tonverhältnisse:&lt;/b&gt; </translation>
    </message>
    <message>
        <location filename="../src/modules/MicrotonalView.cpp" line="934"/>
        <source>Invalid Scala file: </source>
        <translation>Ungültige Scala-Datei: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/CaptureThread.cpp" line="368"/>
        <source>default</source>
        <translation>Voreinstellung</translation>
    </message>
    <message>
        <location filename="../src/modules/View.cpp" line="86"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>
